@@ -1,7 +1,4 @@
 package Test::Unit::Decorator;
-BEGIN {
-  $Test::Unit::Decorator::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 use strict;
 
 use base qw(Test::Unit::Test);
@@ -25,7 +22,7 @@ sub count_test_cases() {
 sub run {
     my $self = shift;
     my ($result) = @_;
-    $self->basic_run($result);
+    $self->{_fTest}->basic_run($result);
 }
 
 sub to_string {
