@@ -1,7 +1,4 @@
 package Test::Unit::Listener;
-BEGIN {
-  $Test::Unit::Listener::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 use Test::Unit::Loader;
 use Carp;
 use strict;
@@ -74,13 +71,14 @@ C<test-E<gt>name()> and keep the rest as details.
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
-(see L<Test::Unit> or the F<AUTHORS> file included in this
-distribution).
+Copyright (c) 2000 Brian Ewins, Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
+Thanks go to the other PerlUnit framework people: 
+Cayte Lindner, J.E. Fritz, Zhon Johansen.
+
 =head1 SEE ALSO
 
 =over 4
