@@ -1,7 +1,4 @@
 package Test::Unit::Loader;
-BEGIN {
-  $Test::Unit::Loader::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 
 use strict;
 
@@ -186,13 +183,14 @@ them), Test::Harness style test files, and directory names.
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
-(see L<Test::Unit> or the F<AUTHORS> file included in this
-distribution).
+Copyright (c) 2000 Brian Ewins.
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
+Thanks go to the other PerlUnit framework people: 
+Christian Lemburg, Cayte Lindner, J.E. Fritz, Zhon Johansen.
+
 =head1 SEE ALSO
 
 =over 4
