@@ -1,7 +1,4 @@
 package Test::Unit::Result;
-BEGIN {
-  $Test::Unit::Result::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 use strict;
 
 use Test::Unit::Debug qw(debug);
@@ -229,13 +226,14 @@ mind it should be apparent what's going on.
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
-(see L<Test::Unit> or the F<AUTHORS> file included in this
-distribution).
+Copyright (c) 2000 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
+Thanks go to the other PerlUnit framework people: 
+Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
+
 =head1 SEE ALSO
 
 =over 4
