@@ -14,59 +14,17 @@ use Class::Inner;
 use vars qw/@ISA/;
 @ISA = qw(Test::Unit::TestCase ExceptionChecker);
 
+sub assertion_has_failed {
+    my $error = shift;
+    return eval {ref($error) && $error->isa('Test::Unit::Failure')};
+}
 
 sub test_assert_equals {
     my $self = shift;
     my $o = TestObject->new();
     $self->assert_equals($o, $o);
-
-    $self->check_failures
-      ("expected 'start o:MyClass=HASH(0x1404343f0) | any o:MyClass=HASH(0x1404343f0) e:start | any o:MyClass=HASH(0x1404343f0) e:in', got 'start o: e: | any o:start e: | any o:in e:'" =>
-       # A false-negative that burned me; problem with is_numeric
-       # Test must be all on one line
-       [ __LINE__, sub { shift->assert_equals("start o:MyClass=HASH(0x1404343f0) | any o:MyClass=HASH(0x1404343f0) e:start | any o:MyClass=HASH(0x1404343f0) e:in", "start o: e: | any o:start e: | any o:in e:"); } ],
-      );
 }
 
-# ...and the root of that problem in test_assert_equals
-sub test_numericness {
-    my $self = shift;
-    my %tests =
-      ( 1	=> 't',
-	0	=> 't',
-## deal with this below
-#  	'0xF00'	=> 'f', # controversial?  but if you +=10 then it's == 10
-	'15e7'	=> 't',
-	'15E7'	=> 't',
-	"not 0"	=> 'f',
-	"not 4"	=> 'f',
-	"  \n 5E2"	=> 't',
-	"  \t 0E0  "	=> 't',
-      );
-    foreach my $str (keys %tests) {
-	my $expect = $tests{$str};
-	my $actual = Test::Unit::Assert::is_numeric($str) ? 't' : 'f';
-	$self->fail("For string '$str', expect $expect but got $actual")
-	  unless $expect eq $actual;
-    }
-
-    my @broken =
-      (sub { my $ret = Test::Unit::Assert::is_numeric("0xF00"); die "Returned '$ret'" },
-       sub { $self->assert_equals("0xF00",  "0x514") },
-       sub { $self->assert_equals("0xBEEF", "junk") },
-       sub { $self->assert_not_equals("0xDEAD", "57005"); die "It did a numeric comparison" },
-      );
-    # loop below is basically an ->assert_dies(qr, @broken) call
-    for (my $i=0; $i<@broken; $i++) {
-	my $ret = eval { $broken[$i]->() };
-	my $err = $@ || "Returned '$ret'";
-	$self->assert_matches(qr{ is ambiguous}, $err);
-	$self->assert_null($ret);
-    }
-    $self->assert_not_equals("junk", "0xBEEF");
-}
-
-
 sub test_assert {
     my $self = shift;
     $self->assert(1);
@@ -79,7 +37,6 @@ sub test_assert {
     $self->assert($coderef, 'a', 'a');
     $self->assert([]);
     $self->assert([ 'foo', 7 ]);
-    my $re_foo = qr/foo/; $re_foo = "$re_foo";
     $self->check_failures(
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(undef) } ],
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(0)   } ],
@@ -87,7 +44,7 @@ sub test_assert {
 
         'bang'  => [ __LINE__, sub { shift->assert(0, 'bang')              } ],
         'bang'  => [ __LINE__, sub { shift->assert('', 'bang')             } ],
-        "'qux' did not match /$re_foo/"
+        "'qux' did not match /(?-xism:foo)/"
                 => [ __LINE__, sub { shift->assert(qr/foo/, 'qux')         } ],
         'bang'  => [ __LINE__, sub { shift->assert(qr/foo/, 'qux', 'bang') } ],
         'a ne b'=> [ __LINE__, sub { shift->assert($coderef, 'a', 'b')     } ],
@@ -173,7 +130,7 @@ sub test_assert_matches {
             => [ __LINE__, sub { shift->assert_matches(1, 2) } ]
     );
 }
-
+    
 sub test_assert_does_not_match {
     my $self = shift;
     $self->assert_does_not_match(qr/ob/, 'fooBar');
@@ -188,11 +145,6 @@ sub test_assert_equals_null {
     $self->assert_equals(undef, undef);
 }
 
-# sub assertion_has_failed {
-#     my $error = shift;
-#     return eval {ref($error) && $error->isa('Test::Unit::Failure')};
-# }
-
 # Not sure this has meaning in Perl
 #  sub test_assert_null_not_equals_null {
 #      my $self = shift;
@@ -260,7 +212,6 @@ sub test_ok_equals {
 sub test_ok_not_equals {
     my $self = shift;
     my $adder = sub { 2+2 };
-    my $re_x = qr/x/; $re_x = "$re_x";
     my @checks = (
         # interface is ok(GOT, EXPECTED);
         q{expected 1, got 0}                => [ 0,      1       ], 
@@ -271,7 +222,7 @@ sub test_ok_not_equals {
         q{expected '', got 'foo'}           => [ 'foo',  ''      ], 
         q{expected 'foo', got ''}           => [ '',     'foo'   ], 
         q{expected 5, got 4}                => [ $adder, 5       ], 
-        qq{'foo' did not match /$re_x/}     => [ 'foo',  qr/x/   ], 
+        q{'foo' did not match /(?-xism:x)/} => [ 'foo',  qr/x/   ], 
     );
     my @tests = ();
     while (@checks) {
@@ -363,10 +314,6 @@ sub test_fail_assert_not_null {
     $self->check_failures(
         '<undef> unexpected'
           => [ __LINE__, sub { shift->assert_not_null(undef) } ],
-        '<undef> unexpected'
-          => [ __LINE__, sub { shift->assert_not_null() } ],
-	  # nb. $self->assert_not_null(@emptylist, "message") is not
-	  # going to do what you expected!
         'Weirdness'
           => [ __LINE__, sub { shift->assert_not_null(undef, 'Weirdness') } ]
     );
@@ -381,63 +328,6 @@ sub test_succeed_assert_not_null {
     $self->assert_not_null(10);
 }
 
-sub test_succeed_assert_isa {
-    my $self = shift;
-    $self->assert_isa('TestObject', TestObject->new);
-    $self->assert_isa('Test::Unit::TestCase', $self);
-    $self->assert_isa(AssertTest => $self);
-## it's not in the spec so don't test it
-#    $self->assert_isa('Test::Unit::TestCase', 'AssertTest'); # assert_isa('Superclass', 'Class') currently fails
-}
-
-sub test_fail_assert_isa {
-    my $self = shift;
-    $self->check_errors(
-        "expected classname was undef; should be using assert_null?"
-          => [ __LINE__, sub { shift->assert_isa(undef, 'FooBar') } ],
-        "expected classname was a reference; args swapped?"
-          => [ __LINE__, sub { shift->assert_isa(TestObject->new, 'TestObject') } ],
-    );
-    $self->check_failures(
-        "expected class 'FooBar', got undef"
-          => [ __LINE__, sub { shift->assert_isa('FooBar', undef) } ],
-        "expected class 'FooBar', got non-reference"
-          => [ __LINE__, sub { shift->assert_isa('FooBar', 123) } ],
-        "expected class 'FooBar', got unblessed reference"
-          => [ __LINE__, sub { shift->assert_isa('FooBar', [ qw( 1 2 3) ]) } ],
-        "expected object of class 'FooBar', got 'TestObject'"
-          => [ __LINE__, sub { shift->assert_isa('FooBar', TestObject->new) } ],
-    );
-}
-
-sub test_succeed_assert_can {
-    my $self = shift;
-    $self->assert_can('new', TestObject->new);
-    $self->assert_can(test_succeed_assert_can => $self);
-## it's not in the spec so don't test it
-#    $self->assert_can(test_succeed_assert_can => 'AssertTest'); # assert_can('method', 'Class') currently fails
-}
-
-sub test_fail_assert_can {
-    my $self = shift;
-    $self->check_errors
-      ("expected method name was undef; should be using assert_null?"
-       => [ __LINE__, sub { shift->assert_can(undef, 'FooBar') } ],
-       "expected method name was a reference; args swapped?"
-       => [ __LINE__, sub { shift->assert_can(TestObject->new, 'new') } ],
-      );
-    $self->check_failures(
-        "expected object that can 'FooBar', got undef"
-          => [ __LINE__, sub { shift->assert_can('FooBar', undef) } ],
-        "expected object that can 'FooBar', got non-object"
-          => [ __LINE__, sub { shift->assert_can('FooBar', 123) } ],
-        "expected object that can 'FooBar', got non-object"
-          => [ __LINE__, sub { shift->assert_can('FooBar', [ qw( 1 2 3) ]) } ],
-        "expected object that can 'blah', but it cannot"
-          => [ __LINE__, sub { shift->assert_can('blah', TestObject->new) } ],
-    );
-}
-
 sub test_assert_deep_equals {
     my $self = shift;
 
@@ -479,66 +369,20 @@ sub test_assert_deep_equals {
     my $differ = sub {
         my ($a, $b) = @_;
         qr/^Structures\ begin\ differing\ at: $ \n
-        \S*\s* \$a .* = .* (?-x:$a)      .* $ \n
-        \S*\s* \$b .* = .* (?-x:$b)/mx;
+           \s* \$a .* = .* $a      .* $ \n
+           \s* \$b .* = .* $b/mx;
     };
 
-    my %families; # key=test-purpose, value=assorted circular structures
-    foreach my $key (qw(orig copy bad_copy)) {
-	my %family = ( john => { name => 'John Doe',
-				 spouse => undef,
-				 children => [],
-			       },
-		       jane => { name   => 'Jane Doe',
-				 spouse => undef,
-				 children => [],
-			       },
-		       baby => { name => 'Baby Doll',
-#				 spouse => undef,
-				 children => [],
-			       },
-		     );
-	$family{john}{spouse} = $family{jane};
-	$family{jane}{spouse} = $family{john};
-	push @{$family{john}{children}}, $family{baby};
-	push @{$family{jane}{children}}, $family{baby};
-	$families{$key} = \%family;
-    }
-    $families{bad_copy}->{jane}{spouse} = $families{bad_copy}->{baby}; # was ->{john}
-
-    # Breakage under test is infinite recursion, to memory exhaustion!
-    # Jump through hoops to avoid killing people's boxes
-    {
-	my $old_isa = \&UNIVERSAL::isa;
-	# Pick on isa() because it'll be called from any deep-ing code
-	local $^W = 0;
-	local *UNIVERSAL::isa = sub {
-	    die "Giving up on deep recursion for assert_deep_equals"
-	      if defined caller(500);
-	    return $old_isa->(@_);
-	};
-	$self->assert_deep_equals($families{orig}, $families{copy});
-    }
-
-    my ($H, $H2, $G) = qw(hello hello goodbye);
-
     my @pairs = (
         'Both arguments were not references' => [ undef, 0 ],
         'Both arguments were not references' => [ 0, undef ],
         'Both arguments were not references' => [ 0, 1     ],
         'Both arguments were not references' => [ 0, ''    ],
         'Both arguments were not references' => [ '', 0    ],
-         $differ->(qw/'ARRAY 'HASH/)     => [ [],      {}      ],
-         $differ->(qw/'ARRAY 'HASH/)     => [ [1,2],   {1,2}   ],
-	 $differ->( "'ARRAY", " undef" ) => [ { 'test' => []},
-					      { 'test' => undef } ],
-	 $differ->( "'ARRAY", 'not exist' ) => [ { 'test' => []}, {} ],
-	 $differ->( 'undef', "'ARRAY" ) => [ { 'test' => undef },
-					     { 'test' => []} ],
-	 $differ->( "''", " undef" ) => [ [ '' ], [ undef ] ],
-	 $differ->( "'undef'", " undef" ) => [ [ 'undef' ], [ undef ] ],
-         $differ->('not exist', "'3'") => [ [1,2],   [1,2,3] ],
-         $differ->("'3'", "not exist") => [ [1,2,3], [1,2]   ],
+         $differ->(qw/ARRAY HASH/)     => [ [],      {}      ],
+         $differ->(qw/ARRAY HASH/)     => [ [1,2],   {1,2}   ],
+         $differ->('not\ exist', "'3'") => [ [1,2],   [1,2,3] ],
+         $differ->("'3'", 'not\ exist') => [ [1,2,3], [1,2]   ],
          $differ->("'wahhhhh'", "'wahhhh'") => [
              $complex,
              {
@@ -554,10 +398,6 @@ sub test_assert_deep_equals {
                  },
              }
          ],
-	 $differ->( 'HASH', 'not exist') => [$families{orig}, $families{bad_copy}], # test may be fragile due to recursion ordering?
-	 $differ->("'3'", "'5'") => [ [ \$H, 3 ], [ \$H2, 5 ] ],
-	 $differ->("'hello'", "'goodbye'") => [ { world => \$H }, { world => \$G } ],
-	 $differ->("'hello'", "'goodbye'") => [ [ \$H, "world" ], [ \$G, "world" ] ],
     );
 
     my @tests = ();
@@ -573,24 +413,6 @@ sub test_assert_deep_equals {
     $self->check_failures(@tests);
 }
 
-# Pasted direct from SF bug #1012115
-# should have been incorporated above...
-sub test_deepequals_scalarrefs {
-    my $self = shift;
-    my ($H, $G) = ("hello", "goodbye");
-    my $a = [ \$H, "world" ];
-    my $b = [ \$G, "world" ];
-    # comparison should fail on list item 0, and tell us what they were
-    eval {
-        $self->assert_deep_equals($a, $b);
-    };
-    my $err = $@;
-    $self->fail("comparison should fail") unless $err;
-    $err =~ s/^/> /mg; # indent for clarity
-    $self->assert_matches(qr/hello/, $err);
-    $self->assert_matches(qr/goodbye/, $err);
-}
-
 # Key = assert_method
 # Value = [[@arg_list],undef/expected exception]
 # FIXME: These should probably be merged with the tests for assert_not_equals()
